@@ -98,6 +98,7 @@ class ft_connector:
 ##################################
 	def build_function_dispatch(self):
 		launch = {}
+		launch['SCRAP'] = self.scrap
 		launch['GET'] = self.get
 		launch['DEL'] = self.delete
 		launch['POST'] = self.post
@@ -130,7 +131,7 @@ class ft_connector:
 ###########################################
 # Scrapping de la data via get sur l'api 42
 ###########################################
-	def get(self, url):
+	def scrap(self, url):
 		i = 0
 		sum_dict = []
 		endpoint = self.build_page(url)
@@ -142,7 +143,7 @@ class ft_connector:
 					continue
 				reply.raise_for_status()
 			except requests.exceptions.HTTPError as err:
-				print(self.RED + '[42 CONNECTOR] ' + str(err) + " on GET " + endpoint + self.DEFAULT)
+				print(self.RED + '[42 CONNECTOR] ' + str(err) + " on SCRAP " + endpoint + self.DEFAULT)
 				return
 			if 'X-Page' in reply.headers :
 				sum_dict += json.loads(reply.text)
@@ -150,12 +151,31 @@ class ft_connector:
 					break
 			else:
 				if self.verbose == True:
-					print(self.GREEN + "[42 CONNECTOR] Success GET on " + url + self.DEFAULT)
+					print(self.GREEN + "[42 CONNECTOR] Success SCRAP on " + url + self.DEFAULT)
 				return (json.loads(reply.text))
 			i+=1
-		print(self.GREEN + "[42 CONNECTOR] Success GET on " + url + self.DEFAULT)
+		print(self.GREEN + "[42 CONNECTOR] Success SCRAP on " + url + self.DEFAULT)
 		return (sum_dict)
 
+##############################################
+# Récupération de la data via get sur l'api 42
+##############################################
+	def get(self, url):
+		if "?" in url:
+			url += "&page[size]=100"
+		else:
+			url += "?page[size]=100"
+		try:
+			reply = requests.get(self.url + url, headers=self.head)
+			if reply.status_code == 429:
+				self.get(url)
+			reply.raise_for_status()
+		except requests.exceptions.HTTPError as err:
+			print(self.RED + '[42 CONNECTOR] ' + str(err) + " on GET " + self.url + url + self.DEFAULT)
+			return
+		print(self.GREEN + "[42 CONNECTOR] Success GET on " + url + self.DEFAULT)
+		return (json.loads(reply.text))
+
 ######################################################
 # Post de la data sur un url en fonction du body donné
 ######################################################
