@@ -121,10 +121,16 @@ class notion_connector:
 			ret.append(data_line)
 		return (ret)
 
-################
-# Format Db
-################
-
+#################################################
+# Search title in db and return it if exist, else return None
+#################################################
+	def getTitle(self, db, title):
+		print(title)
+		for line in db:
+			if 'title' in line.keys():
+				if line['title'] == title:
+					return (line)
+		return None
 
 #################################################
 # Permet de mettre à jour une des lignes de la db
@@ -140,7 +146,6 @@ class notion_connector:
 			i = True
 		if i == False:
 			return
-		self.put_in_file(data, 'data.json')
 		url = self.url + '/pages/' + pageId
 		try :
 			reply = requests.patch(url, headers=self.head, data=json.dumps(data))
@@ -177,16 +182,25 @@ class notion_connector:
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on PATCH ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
 
+###################################
+# Retourne le champs title de la db
+###################################
+	def getTitleProperties(self, db):
+		for i in db['properties'].items():
+			if i[1]['type'] == 'Title':
+				return i[0]
+
 ############################################################################
 # Rajoute une ligne à la base de donnée, avec pour title le nom mis en param
 ############################################################################
 	def addPageDb(self, dbId, name):
+		title = self.getTitleProperties(self.getDb(dbId))
 		url = self.url + '/pages'
 		data = {
 			"parent": { "type": "database_id",
 						"database_id": dbId },
 			"properties": {
-				"Nom": {
+				title: {
 					"title": [
 						{
 							"text": {
